@@ -21,8 +21,8 @@ def main():
 
     # 新增记录
     try:
-        record = create_bitable_record(app_token, table_id, fields)
-        print(f"新增记录成功: {lark.JSON.marshal(record)}")
+        result = create_bitable_record(app_token, table_id, fields)
+        print(f"新增记录成功: {lark.JSON.marshal(result)}")
     except Exception as e:
         print(f"新增记录失败: {e}")
 
