@@ -8,7 +8,7 @@ from ..lark_bitable import (
     search_bitable_records_with_page,
 )
 from .product import Product
-from .encoder import CustomEncoder
+from ..lark_bitable import RecordEncoder
 
 
 def main():
@@ -50,7 +50,7 @@ def main():
 
     print(f"总记录数: {total}")
     print(
-        f"第一页: {json.dumps(records, cls=CustomEncoder, indent=2, ensure_ascii=False)}"
+        f"第一页: {json.dumps(records, cls=RecordEncoder, indent=2, ensure_ascii=False)}"
     )
 
 
