@@ -23,8 +23,8 @@ def main():
 
     # 更新记录
     try:
-        record = update_bitable_record(app_token, table_id, record_id, fields)
-        print(f"更新记录成功: {lark.JSON.marshal(record)}")
+        result = update_bitable_record(app_token, table_id, record_id, fields)
+        print(f"更新记录成功: {lark.JSON.marshal(result)}")
     except Exception as e:
         print(f"更新记录失败: {e}")
 
