@@ -1,7 +1,9 @@
 """飞书多维表格产品数据模型"""
 
 from dataclasses import dataclass, field
+import datetime
 from decimal import Decimal
+from typing import Optional
 
 from ..lark_bitable import BitableFieldType, bitable_field_metadata, bitable_record
 from ..lark_bitable.bitable_record import BitableBaseRecord
@@ -37,3 +39,11 @@ class Product(BitableBaseRecord):
         default="",
         metadata=bitable_field_metadata("shop_code", BitableFieldType.STRING),
     )
+    create_time: Optional[datetime] = field(
+        default=None,
+        metadata=bitable_field_metadata("create_time", BitableFieldType.DATE),
+    )
+    update_time: Optional[datetime] = field(
+        default=None,
+        metadata=bitable_field_metadata("update_time", BitableFieldType.DATE),
+    )
