@@ -1,7 +1,9 @@
 from abc import ABC, abstractmethod
 from decimal import Decimal
 from enum import Enum
-from typing import Any, Dict, List, Union
+from optparse import Option
+import re
+from typing import Any, Dict, List, Optional, Union
 from datetime import datetime
 
 
@@ -16,25 +18,36 @@ class BaseBitableFieldType(ABC):
 
 
 class TextBitableFieldType(BaseBitableFieldType):
-    def escape_out(self, value: str) -> str:
+    def escape_out(self, value: str | None) -> Optional[str]:
+        if value is None:
+            return None
         return value
 
-    def escape_in(self, value: Any) -> str:
-        if not isinstance(value, list) or len(value) == 0:
-            raise ValueError("TextBitableFieldType escape_in value must be list")
-
-        for item in value:
-            if not isinstance(item, dict):
-                continue
-            return item.get("text", "")
-        return ""
+    def escape_in(self, value: Any | None) -> Optional[str]:
+        if value is None:
+            return None
+        if isinstance(value, str):
+            return value
+        if isinstance(value, list):
+            if len(value) <= 0:
+                return ""
+            for item in value:
+                if not isinstance(item, dict):
+                    continue
+                return item.get("text", "")
+            return ""
+        raise ValueError("TextBitableFieldType escape_in value must be str or list")
 
 
 class StringBitableFieldType(BaseBitableFieldType):
-    def escape_out(self, value: str) -> str:
+    def escape_out(self, value: str | None) -> Optional[str]:
+        if value is None:
+            return None
         return value
 
-    def escape_in(self, value: Any) -> str:
+    def escape_in(self, value: Any | None) -> Optional[str]:
+        if value is None:
+            return None
         if not isinstance(value, str):
             raise ValueError("StringBitableFieldType escape_in value must be str")
         return value
@@ -47,33 +60,32 @@ class DateBitableFieldType(BaseBitableFieldType):
         "%Y-%m-%dT%H:%M:%S%z",  # ISO format with timezone
     ]
 
-    def escape_out(self, value: str) -> int:
-        if not isinstance(value, str):
-            raise ValueError("DateBitableFieldType escape_out value must be str")
+    def escape_out(self, value: datetime | None) -> Optional[int]:
+        if value is None:
+            return None
 
-        for fmt in self._date_formats:
-            try:
-                dt = datetime.strptime(value, fmt)
-                return int(dt.timestamp() * 1000)
-            except ValueError:
-                continue
+        if isinstance(value, datetime):
+            return int(value.timestamp() * 1000)
 
-        raise ValueError(
-            f"DateBitableFieldType escape_out cannot parse date string: {value}"
-        )
+        raise ValueError(f"DateBitableFieldType escape_out cannot parse date: {value}")
 
-    def escape_in(self, value: Any) -> str:
+    def escape_in(self, value: Any | None) -> Optional[datetime]:
+        if value is None:
+            return None
         if not isinstance(value, int):
             raise ValueError("DateBitableFieldType escape_in value must be int")
-        dt = datetime.fromtimestamp(value / 1000)
-        return dt.strftime(self._date_formats[1])  # 使用 yyyy-mm-dd hh:mm:ss 格式
+        return datetime.fromtimestamp(value / 1000)
 
 
 class UserBitableFieldType(BaseBitableFieldType):
-    def escape_out(self, value: str) -> List[Dict[str, str]]:
+    def escape_out(self, value: str | None) -> Optional[List[Dict[str, str]]]:
+        if value is None:
+            return None
         return [{"id": str(value)}]
 
-    def escape_in(self, value: Any) -> str:
+    def escape_in(self, value: Any | None) -> Optional[str]:
+        if value is None:
+            return None
         if not isinstance(value, list) or len(value) == 0:
             raise ValueError("UserBitableFieldType escape_in value must be list")
         for item in value:
@@ -84,36 +96,48 @@ class UserBitableFieldType(BaseBitableFieldType):
 
 
 class IntBitableFieldType(BaseBitableFieldType):
-    def escape_out(self, value: int) -> int:
+    def escape_out(self, value: int | None) -> Optional[int]:
+        if value is None:
+            return None
         if not isinstance(value, int):
             raise ValueError("IntBitableFieldType escape_out value must be int")
         return value
 
-    def escape_in(self, value: Any) -> int:
+    def escape_in(self, value: Any | None) -> Optional[int]:
+        if value is None:
+            return None
         if not isinstance(value, int):
             raise ValueError("IntBitableFieldType escape_in value must be int")
         return value
 
 
 class FloatBitableFieldType(BaseBitableFieldType):
-    def escape_out(self, value: float) -> float:
+    def escape_out(self, value: float | None) -> Optional[float]:
+        if value is None:
+            return None
         if not isinstance(value, float):
             raise ValueError("FloatBitableFieldType escape_out value must be float")
         return value
 
-    def escape_in(self, value: Any) -> float:
+    def escape_in(self, value: Any | None) -> Optional[float]:
+        if value is None:
+            return None
         if not isinstance(value, float):
             raise ValueError("FloatBitableFieldType escape_in value must be float")
         return value
 
 
 class DecimalBitableFieldType(BaseBitableFieldType):
-    def escape_out(self, value: Decimal) -> float:
+    def escape_out(self, value: Decimal | None) -> Optional[float]:
+        if value is None:
+            return None
         if not isinstance(value, Decimal):
             raise ValueError("DecimalBitableFieldType escape_out value must be Decimal")
         return float(value)
 
-    def escape_in(self, value: float) -> Decimal:
+    def escape_in(self, value: float | None) -> Optional[Decimal]:
+        if value is None:
+            return None
         if not isinstance(value, (int, float, str)):
             raise ValueError(
                 "DecimalBitableFieldType escape_in value must be number or string"
@@ -126,6 +150,20 @@ class DecimalBitableFieldType(BaseBitableFieldType):
             )
 
 
+class CheckBoxBitableFieldType(BaseBitableFieldType):
+    def escape_out(self, value: bool | None) -> Optional[bool]:
+        if value is None:
+            return None
+        return value
+
+    def escape_in(self, value: Any | None) -> Optional[bool]:
+        if value is None:
+            return None
+        if isinstance(value, bool):
+            return value
+        raise ValueError("CheckBoxBitableFieldType escape_in value must be bool")
+
+
 class BitableFieldType(Enum):
     """多维表格字段类型枚举
 
@@ -145,3 +183,4 @@ class BitableFieldType(Enum):
     DECIMAL = DecimalBitableFieldType()
     DATE = DateBitableFieldType()
     USER = UserBitableFieldType()
+    CHECKBOX = UserBitableFieldType()
