@@ -54,7 +54,7 @@ def update_bitable_record(
 
     # 处理失败返回
     if not response.success():
-        error_msg = f"更新多维表格记录失败, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}"
+        error_msg = f"更新多维表格记录失败, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, 入参: app_token={app_token}, table_id={table_id}, record_id={record_id}, fields={json.dumps(fields, ensure_ascii=False)}"
         lark.logger.error(error_msg)
         raise Exception(error_msg)
 
