@@ -6,7 +6,7 @@
 
 import json
 import lark_oapi as lark
-from lark_oapi.api.wiki.v2 import GetNodeSpaceRequest
+from lark_oapi.api.wiki.v2 import GetNodeSpaceRequest, Node
 
 
 """飞书知识空间工具
@@ -21,7 +21,7 @@ from typing import Dict, Any
 from ..lark_client import client
 
 
-def get_space_node(token: str, obj_type: str = "wiki") -> Dict[str, Any]:
+def get_space_node(token: str, obj_type: str = "wiki") -> Node:
     """
     获取知识空间节点信息
 
@@ -30,7 +30,7 @@ def get_space_node(token: str, obj_type: str = "wiki") -> Dict[str, Any]:
         obj_type: 对象类型，默认为"wiki"
 
     Returns:
-        Dict[str, Any]: 知识空间节点信息字典
+        Node: 知识空间节点信息
 
     Raises:
         Exception: 获取节点信息失败时抛出异常
@@ -47,14 +47,4 @@ def get_space_node(token: str, obj_type: str = "wiki") -> Dict[str, Any]:
         lark.logger.error(error_msg)
         raise Exception(error_msg)
 
-    # 从raw.content中解析数据
-    if response.raw and response.raw.content:
-        try:
-            response_data = json.loads(response.raw.content.decode("utf-8"))
-            return response_data.get("data", {})
-        except (json.JSONDecodeError, KeyError) as e:
-            error_msg = f"解析响应数据失败: {e}"
-            lark.logger.error(error_msg)
-            raise Exception(error_msg)
-    else:
-        raise Exception("响应数据为空")
+    return response.data.node
